@@ -1,11 +1,11 @@
-pick.model <-  function(...) UseMethod("pick.model")
+pick.model <-  function(object, ...) UseMethod("pick.model", object)
 
 pick.model.HOF.list <- function(object, ...) {
    out <- sapply(object, function(x) pick.model.HOF(object=x,  ...))
   return(out)
 }
 
-pick.model.HOF <- function (object, level = 0.95, test = c('AICc', 'BIC', 'AIC','Dev'), modeltypes, penal = 'df', gam = FALSE, selectMethod = c('bootselect', 'IC.weight', 'pick.model'), silent = FALSE, ...) {
+pick.model.HOF <- function (object, level = 0.95, test = c('AICc', 'BIC', 'AIC','Dev'), modeltypes, penal = 'df', gam = FALSE, selectMethod = c('bootselect.lower', 'bootselect.always', 'IC.weight', 'pick.model'), silent = FALSE, ...) {
   selectMethod <- match.arg(selectMethod)
   if(is.null(object$bootstrapmodels) & selectMethod != 'pick.model') {
     if(getOption("eHOF.bootselectmessage")) {
@@ -47,34 +47,42 @@ pick.model.HOF <- function (object, level = 0.95, test = c('AICc', 'BIC', 'AIC',
       p <- penal[match(names(penal), names(object$models))]
       ic <- -2 * logLik(object) + k * p
       ic <- ic[names(ic) %in% modeltypes]
-      model <- (names(ic[!rejectedmodels]))[which.min(ic[!rejectedmodels])]
+      model <- names(ic[!rejectedmodels])[which.min(ic[!rejectedmodels])]
   }
   if (test == "AICc") {
       k <-  2
       p <- penal[match(names(penal), names(object$models))]
       ic <- -2 * logLik(object) + k * p + (2*k*(k + 1))/(object$nobs - k - 1)
       ic <- ic[names(ic) %in% modeltypes]
-      model <- (names(ic[!rejectedmodels]))[which.min(ic[!rejectedmodels])]
+      model <- names(ic[!rejectedmodels])[which.min(ic[!rejectedmodels])]
   }
   if( test == 'BIC') {
       k <- log(object$nobs)
       p <- penal[match(names(penal), names(object$models))]
       ic <- -2 * logLik(object) + k * p
       ic <- ic[names(ic) %in% modeltypes]
-      model <- (names(ic[!rejectedmodels]))[which.min(ic[!rejectedmodels])]
+      model <- names(ic[!rejectedmodels])[which.min(ic[!rejectedmodels])]
   }
   if (test == "Dev") {
       ic <- deviance(object)
       ic <- ic[names(ic) %in% modeltypes]
-      model <- (names(ic[!rejectedmodels]))[which.min(ic[!rejectedmodels])]
+      model <- names(ic[!rejectedmodels])[which.min(ic[!rejectedmodels])]
   }
-  if(selectMethod == 'bootselect') {
+
+  if(selectMethod == 'bootselect.lower') {
+    # modboot <- names(ic[!rejectedmodels])[which.min(ic[!rejectedmodels])]    
     modboot <- names(which.max(table(object$bootstrapmodels)))
-    if(modboot != model) 
-      if(!silent) message(object$y.name, ': Most frequent bootstrap model (',modboot, ') not equal to original choice (', model, ',',  object$bootstraptest,') by ', test, ' test.', sep='')
-    model <- modboot
+    if(eHOF.modelnames[match(modboot, eHOF.modelnames)] < eHOF.modelnames[match(model, eHOF.modelnames)] )
+      if(!silent) message(object$y.name, ': Most frequent bootstrap model (',modboot, ') lower than original choice (', model, ',',  object$bootstraptest,') by ', test, ' test.', sep='')
+      if(!modboot %in% names(rejectedmodels)[rejectedmodels]) model <- modboot
   }
-  if(selectMethod == 'IC.weights') {
+  if(selectMethod == 'bootselect.always') {
+    modboot <- names(which.max(table(object$bootstrapmodels)))
+    if(modboot != model )
+      if(!silent) message(object$y.name, ': Most frequent bootstrap model (',modboot, ') not equal to original choice (', model, ',',  object$bootstraptest,') by ', test, ' test.', sep='')
+    if(!modboot %in% names(rejectedmodels)[rejectedmodels]) model <- modboot
+  }
+if(selectMethod == 'IC.weights') {
 #     cat('Stabilisation test for models V and VII: ')
 #     print(table(object$bootstrapmodels)[modboot])
 #     if(table(object$bootstrapmodels)[modboot] <= length(object$bootstrapmodels)/2) {
@@ -84,9 +92,9 @@ pick.model.HOF <- function (object, level = 0.95, test = c('AICc', 'BIC', 'AIC',
       d.AICc <- AICc - min(AICc, na.rm=TRUE)
       AICc.W <- round(exp(-0.5*AICc)/ sum(exp(-0.5*AICc), na.rm=TRUE),4)
       model.weight <- names(which.max(AICc.W[!rejectedmodels]))
-      if(model.weight != model) { 
-        if(!silent) message('Selection method: Highest ', test, ' weights.\n', object$y.name, ': Original model choice (', model, ') not equal to the model with highest IC weight (', model.weight, ') is chosen instead.', sep='')
-      	model <- model.weight
+      if(eHOF.modelnames[match(model.weight, eHOF.modelnames)] < eHOF.modelnames[match(model, eHOF.modelnames)]) {
+        if(!silent) message('Selection method: Highest ', test, ' weights.\n', object$y.name, ': Original model choice (', model, ') lower than the model with highest IC weight (', model.weight, ') is chosen instead.', sep='')
+        if(!model.weight %in% names(rejectedmodels)[rejectedmodels]) model <- model.weight
 	  }
   }
   return(model)
